@@ -62,10 +62,7 @@ def _compute_array_job_index():
 
 
 def _dispatch_execute(
-    ctx: FlyteContext,
-    task_def: PythonTask,
-    inputs_path: str,
-    output_prefix: str,
+    ctx: FlyteContext, task_def: PythonTask, inputs_path: str, output_prefix: str,
 ):
     """
     Dispatches execute to PythonTask
@@ -118,9 +115,12 @@ def _dispatch_execute(
                 e.error_code, e.verbose_message, e.kind, _execution_models.ExecutionError.ErrorKind.USER
             )
         )
-        logger.error("!! Begin User Error Captured by Flyte !!")
-        logger.error(e.verbose_message)
-        logger.error("!! End Error Captured by Flyte !!")
+
+        logger.error(
+            "\n".join(
+                ["\n!! Begin User Error Captured by Flyte !!", e.verbose_message, "!! End Error Captured by Flyte !!\n"]
+            )
+        )
 
     # Handle system-scoped errors
     except _scoped_exceptions.FlyteScopedSystemException as e:
@@ -219,11 +219,7 @@ def setup_execution(
         logger.debug(f"Checkpointer created with source {prev_checkpoint} and dest {checkpoint_path}")
 
     execution_parameters = ExecutionParameters(
-        execution_id=_identifier.WorkflowExecutionIdentifier(
-            project=exe_project,
-            domain=exe_domain,
-            name=exe_name,
-        ),
+        execution_id=_identifier.WorkflowExecutionIdentifier(project=exe_project, domain=exe_domain, name=exe_name,),
         execution_date=_datetime.datetime.utcnow(),
         stats=_get_stats(
             cfg=StatsConfig.auto(),
@@ -247,16 +243,14 @@ def setup_execution(
 
     try:
         file_access = FileAccessProvider(
-            local_sandbox_dir=tempfile.mkdtemp(prefix="flyte"),
-            raw_output_prefix=raw_output_data_prefix,
+            local_sandbox_dir=tempfile.mkdtemp(prefix="flyte"), raw_output_prefix=raw_output_data_prefix,
         )
     except TypeError:  # would be thrown from DataPersistencePlugins.find_plugin
         logger.error(f"No data plugin found for raw output prefix {raw_output_data_prefix}")
         raise
 
     es = ctx.new_execution_state().with_params(
-        mode=ExecutionState.Mode.TASK_EXECUTION,
-        user_space_params=execution_parameters,
+        mode=ExecutionState.Mode.TASK_EXECUTION, user_space_params=execution_parameters,
     )
     cb = ctx.new_builder().with_file_access(file_access).with_execution_state(es)
 
@@ -268,9 +262,7 @@ def setup_execution(
         ssb.version = tk_version
         if dynamic_addl_distro:
             ssb.fast_serialization_settings = FastSerializationSettings(
-                enabled=True,
-                destination_dir=dynamic_dest_dir,
-                distribution_location=dynamic_addl_distro,
+                enabled=True, destination_dir=dynamic_dest_dir, distribution_location=dynamic_addl_distro,
             )
         cb = cb.with_serialization_settings(ssb.build())
 
@@ -279,10 +271,7 @@ def setup_execution(
 
 
 def _handle_annotated_task(
-    ctx: FlyteContext,
-    task_def: PythonTask,
-    inputs: str,
-    output_prefix: str,
+    ctx: FlyteContext, task_def: PythonTask, inputs: str, output_prefix: str,
 ):
     """
     Entrypoint for all PythonTask extensions
@@ -330,11 +319,7 @@ def _execute_task(
         raise Exception("cannot be <1")
 
     with setup_execution(
-        raw_output_data_prefix,
-        checkpoint_path,
-        prev_checkpoint,
-        dynamic_addl_distro,
-        dynamic_dest_dir,
+        raw_output_data_prefix, checkpoint_path, prev_checkpoint, dynamic_addl_distro, dynamic_dest_dir,
     ) as ctx:
         resolver_obj = load_object_from_module(resolver)
         # Use the resolver to load the actual task object
@@ -437,9 +422,7 @@ def _pass_through():
 @_click.option("--dynamic-dest-dir", required=False)
 @_click.option("--resolver", required=False)
 @_click.argument(
-    "resolver-args",
-    type=_click.UNPROCESSED,
-    nargs=-1,
+    "resolver-args", type=_click.UNPROCESSED, nargs=-1,
 )
 def execute_task_cmd(
     inputs,
@@ -518,9 +501,7 @@ def fast_execute_task_cmd(additional_distribution: str, dest_dir: str, task_exec
 @_click.option("--checkpoint-path", required=False)
 @_click.option("--prev-checkpoint", required=False)
 @_click.argument(
-    "resolver-args",
-    type=_click.UNPROCESSED,
-    nargs=-1,
+    "resolver-args", type=_click.UNPROCESSED, nargs=-1,
 )
 def map_execute_task_cmd(
     inputs,
