@@ -977,7 +977,9 @@ def flyte_entity_call_handler(entity: Union[SupportsNodeCreation], *args, **kwar
 
     ctx = FlyteContextManager.current_context()
 
-    if ctx.compilation_state is not None and ctx.compilation_state.mode == 1:
+    if ctx.inspect_objects_only:
+        return
+    elif ctx.compilation_state is not None and ctx.compilation_state.mode == 1:
         return create_and_link_node(ctx, entity=entity, **kwargs)
     elif ctx.execution_state is not None and ctx.execution_state.mode == ExecutionState.Mode.LOCAL_WORKFLOW_EXECUTION:
         if ctx.execution_state.branch_eval_mode == BranchEvalMode.BRANCH_SKIPPED:
