@@ -119,7 +119,11 @@ def _enforce_trailing_slash(path: str):
 
 _session = requests.Session()
 
-_adapter = HTTPAdapter(max_retries=Retry(status_forcelist=[429, 500, 502, 503, 504], backoff_factor=1))
+_adapter = HTTPAdapter(
+    max_retries=Retry(
+        status_forcelist=[429, 500, 502, 503, 504], backoff_factor=1, allowed_methods=["GET", "PUT", "POST"]
+    )
+)
 _session.mount("https://", _adapter)
 _session.mount("http://", _adapter)
 
@@ -159,11 +163,20 @@ class LatchPersistence(DataPersistence):
             raise ValueError(f"expected a Latch URL (latch://...): {remote_path}")
 
         attempts = 0
-        r = _session.post(
-            self._latch_endpoint + "/api/object-exists-at-url",
-            json={"object_url": remote_path, "execution_name": _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")},
-            timeout=90,
-        )
+        while True:
+            try:
+                r = _session.post(
+                    self._latch_endpoint + "/api/object-exists-at-url",
+                    json={"object_url": remote_path, "execution_name": _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")},
+                    timeout=90,
+                )
+                break
+            except requests.exceptions.ConnectionError:
+                attempts += 1
+                if attempts >= 3:
+                    raise e
+                time.sleep(0.1 * 2**attempts)
+
         if r.status_code != 200:
             raise FlyteUserException("failed to check if object exists at url `{}`".format(remote_path))
 
@@ -302,27 +315,16 @@ class LatchPersistence(DataPersistence):
         internal_execution_id = _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")
 
         if internal_execution_id is not None:
-
-            attempts = 0
-            while True:
-                try:
-                    r = _session.post(
-                        endpoint + "/api/begin-upload",
-                        json={
-                            "object_url": to_path,
-                            "nrof_parts": nrof_parts,
-                            "content_type": content_type,
-                            "execution_name": internal_execution_id,
-                        },
-                        timeout=90,
-                    )
-                    break
-                except requests.exceptions.ConnectionError as e:
-                    attempts += 1
-                    if attempts >= 3:
-                        raise e
-                    time.sleep(0.1 * 2**attempts)
-
+            r = _session.post(
+                endpoint + "/api/begin-upload",
+                json={
+                    "object_url": to_path,
+                    "nrof_parts": nrof_parts,
+                    "content_type": content_type,
+                    "execution_name": internal_execution_id,
+                },
+                timeout=90,
+            )
             if r.status_code != 200:
                 raise FlyteUserException("failed to get presigned upload urls for `{}`".format(to_path))
 
